Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(70)

Unified Diff: src/isolate.h

Issue 8403037: Make C++ to JS transition faster by avoiding JavaScriptFrameIterator in SaveContext. (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 9 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/isolate-inl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/isolate.h
diff --git a/src/isolate.h b/src/isolate.h
index 5453bf249ad3f756cbd97944d94dd018f79aa389..75d6c7f0a9f016266e2869c7f60a510250817ac9 100644
--- a/src/isolate.h
+++ b/src/isolate.h
@@ -1245,9 +1245,10 @@ class SaveContext BASE_EMBEDDED {
Handle<Context> context() { return context_; }
SaveContext* prev() { return prev_; }
- // Returns true if this save context is below a given JavaScript frame.
- bool below(JavaScriptFrame* frame) {
- return (js_sp_ == 0) || (frame->sp() < js_sp_);
+ // Returns true if this save context is above a given JavaScript frame.
+ bool IsAboveFrame(JavaScriptFrame* frame) {
Kevin Millikin (Chromium) 2011/10/28 11:09:08 Let's rename this to use "Below", and you can chan
+ // Every frame is below topmost SaveContext.
+ return (c_entry_fp_ == 0) || (c_entry_fp_ > frame->sp());
}
private:
@@ -1256,7 +1257,7 @@ class SaveContext BASE_EMBEDDED {
Handle<Context> dummy_;
#endif
SaveContext* prev_;
- Address js_sp_; // The top JS frame's sp when saving context.
+ Address c_entry_fp_;
};
« no previous file with comments | « no previous file | src/isolate-inl.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698